## dbt-bigquery 1.11.0-b1 - October 07, 2025

### Features

- Add support for BigQuery resource tags via `resource_tags` configuration option ([#565](https://github.com/dbt-labs/dbt-adapters/issues/565), [#577](https://github.com/dbt-labs/dbt-adapters/issues/577))
- Support the updating of incremental model description after initial creation ([#585](https://github.com/dbt-labs/dbt-adapters/issues/585))
- Add `enable_change_history` option for models on BigQuery. ([#1206](https://github.com/dbt-labs/dbt-adapters/issues/1206))
- Add support for scalar functions ([#1290](https://github.com/dbt-labs/dbt-adapters/issues/1290))

### Fixes

- BigFrames notebook execution when using a service account with oauth ([#1231](https://github.com/dbt-labs/dbt-adapters/issues/1231))
- Ensure we have exchanged a refresh-token for a token prior to detemining notebook user in BigFrames ([#1219](https://github.com/dbt-labs/dbt-adapters/issues/1219))
- Fix references to function properties in function macros ([#1365](https://github.com/dbt-labs/dbt-adapters/issues/1365))

### Under the Hood

- Validate notebooks authorization request has succeeded ([#1307](https://github.com/dbt-labs/dbt-adapters/issues/1307))
- Emit SQLQueryStatus during query execution ([#1327](https://github.com/dbt-labs/dbt-adapters/issues/1327))

### Contributors
- [@Robin_CHESNE](https://github.com/Robin_CHESNE) ([#1206](https://github.com/dbt-labs/dbt-adapters/issues/1206))
- [@jspenmar](https://github.com/jspenmar) ([#1231](https://github.com/dbt-labs/dbt-adapters/issues/1231))
- [@kiwamizamurai](https://github.com/kiwamizamurai) ([#585](https://github.com/dbt-labs/dbt-adapters/issues/585))
- [@tnk-ysk](https://github.com/tnk-ysk) ([#565](https://github.com/dbt-labs/dbt-adapters/issues/565), [#577](https://github.com/dbt-labs/dbt-adapters/issues/577))
